@@ -4,6 +4,8 @@ import sys
 import subprocess
 import logging
 import platform
+import traceback
+
 from func_timeout import func_timeout, FunctionTimedOut
 
 
@@ -63,6 +65,12 @@ class Util(object):
             if p.returncode != 0:  # 如果 returncode 非 0，引发异常
                 raise NameError('{} 命令 return code {} 非 0\nout:\n{}'.format(arg, p.returncode, out))
 
+        try:
+            logging.debug('out[: 100]: {}'.format(out[: 100]))
+        except Exception as e:
+            error_str = traceback.format_exc()
+            logging.debug('out log error: {}'.format(error_str))
+
         return out
 
     @staticmethod
